@@ -71,7 +71,9 @@ def delete_config(section):
 def read_config(section):
     if os.path.exists(configfile):
         for opt in options:
-            if config.has_option(section, opt):
+            if not config.has_option(section, opt):
+                options[opt] = ''
+            else:
                 options[opt] = config.get(section, opt)
 
 
@@ -84,12 +86,27 @@ def list_profiles():
     return profiles_list
 
 
+# Check for given host in freerdp's known_hosts file before connecting
+def check_known_hosts(host):
+    known_hosts = '%s/.config/freerdp/known_hosts' % homedir
+    try:
+        with open(known_hosts, 'r') as f:
+            read_data = f.read()
+        match = re.search(host, read_data)
+        if match:
+            return True
+        else:
+            return False
+    except IOError:
+        return False
+
+
 # Run the selected RDP client - currently rdesktop or xfreerdp
 def run_program(window):
     # CLI parameters for each RDP client we support.  stdopts are always used.
     client_opts = {
         'rdesktop': {
-            'stdopts': ['rdesktop', '-ken-us', '-a16'],
+            'stdopts': ['rdesktop', '-a16'],
             'host': '',
             'user': '-u',
             'geometry': '-g',
@@ -98,7 +115,7 @@ def run_program(window):
             'fullscreen': '-f'
         },
         'xfreerdp': {
-            'stdopts': ['xfreerdp', '/cert-ignore', '-sec-nla', '+clipboard'],
+            'stdopts': ['xfreerdp', '+clipboard'],
             'host': '/v:',
             'user': '/u:',
             'geometry': '/size:',
@@ -144,11 +161,22 @@ def run_program(window):
                   + '%s' % str.strip(options['host']))
     # Clean up params list to make it shell compliant
     cmdline = shlex.split(' '.join(params))
-    # Print the command line that we constructed to the terminal
-    print 'Command to execute: \n' + ' '.join(str(x) for x in cmdline)
+    terminal_needed(options['host'], cmdline)
     return cmdline
 
 
+# Open a terminal when freerdp needs user input
+def terminal_needed(host, cmdline):
+    def prepend_terminal():
+        cmdline.insert(0, '-x')
+        cmdline.insert(0, 'x-terminal-emulator')
+    if cmdline[0] == 'xfreerdp':
+        if '-sec-nla' not in cmdline:
+            prepend_terminal()
+        if '/cert-ignore' not in cmdline and check_known_hosts(host) is False:
+            prepend_terminal()
+
+
 # Thread for RDP client launch feedback in UI
 class WorkerThread(threading.Thread):
     def __init__(self, callback, cmdline):
@@ -160,6 +188,8 @@ class WorkerThread(threading.Thread):
 
     # Start the client and wait some seconds for errors
     def run(self):
+        # Print the command line that we constructed to the terminal
+        print 'Command to execute: \n' + ' '.join(str(x) for x in self.cmdline)
         p = subprocess.Popen(self.cmdline, stderr=subprocess.PIPE)
         start_time = time.time()
         while p.poll() is None:
@@ -561,7 +591,7 @@ e.g. "1024x768" or "80%"''')
     def on_about(self, widget):
         about = Gtk.AboutDialog()
         about.set_program_name("Rocket Depot")
-        about.set_version("0.17")
+        about.set_version("0.18")
         about.set_copyright("2014 David Roble")
         about.set_comments("rdesktop/xfreerdp Frontend")
         about.set_website("https://github.com/robled/rocket-depot")
